@@ -29,6 +29,12 @@ from flake8_pie.pie796_prefer_unique_enums import pie786_prefer_unique_enum
 from flake8_pie.pie797_no_unnecessary_if_expr import pie797_no_unnecessary_if_expr
 from flake8_pie.pie798_no_unnecessary_class import pie798_no_unnecessary_class
 from flake8_pie.pie799_prefer_col_init import pie799_prefer_col_init
+from flake8_pie.pie800_no_unnecessary_spread import pie800_no_unnecessary_spread
+from flake8_pie.pie801_prefer_simple_return import pie801_prefer_simple_return
+from flake8_pie.pie802_prefer_simple_any_all import pie802_prefer_simple_any_all
+from flake8_pie.pie803_prefer_logging_interpolation import (
+    pie803_prefer_logging_interpolation,
+)
 
 
 @dataclass(frozen=True)
@@ -84,11 +90,14 @@ class Flake8PieVisitor(ast.NodeVisitor):
     def visit_Call(self, node: ast.Call) -> None:
         pie784_celery_crontab_args(node, self.errors)
         pie785_celery_require_tasks_expire(node, self.errors)
+        pie802_prefer_simple_any_all(node, self.errors)
+        pie803_prefer_logging_interpolation(node, self.errors)
 
         self.generic_visit(node)
 
     def visit_Dict(self, node: ast.Dict) -> None:
         pie785_celery_require_tasks_expire(node, self.errors)
+        pie800_no_unnecessary_spread(node, self.errors)
 
         self.generic_visit(node)
 
@@ -134,6 +143,7 @@ class Flake8PieVisitor(ast.NodeVisitor):
         pie781_assign_and_return(node, self.errors)
         pie790_no_unnecessary_pass(node, self.errors)
         pie799_prefer_col_init(node, self.errors)
+        pie801_prefer_simple_return(node, self.errors)
 
     def visit_Module(self, node: ast.Module) -> None:
         self._visit_body(node)
