@@ -7,7 +7,11 @@ from flake8_pie.base import Error
 
 
 def pie791_no_pointless_statements(node: ast.Expr, errors: list[Error]) -> None:
-    if isinstance(node.value, ast.Compare):
+    if isinstance(node.value, ast.Compare) or (
+        isinstance(node.value, ast.Call)
+        and isinstance(node.value.func, ast.Name)
+        and node.value.func.id == "super"
+    ):
         errors.append(PIE791(lineno=node.lineno, col_offset=node.col_offset))
 
 
