@@ -7,10 +7,20 @@ from typing import Sequence
 from flake8_pie.base import Error
 
 
-def _is_dataclass_like_stmt(stmt: ast.stmt) -> bool:
-    return isinstance(stmt, ast.AnnAssign) or (
-        isinstance(stmt, ast.FunctionDef) and stmt.name == "__init__"
-    )
+def _has_dataclass_like_body(body: Sequence[ast.stmt]) -> bool:
+    """
+    Has at least one dataclass like assignment stmt and doesn't have any
+    methods besides __init__.
+    """
+    found_assignment_stmt = False
+    for stmt in body:
+        if isinstance(stmt, ast.FunctionDef) and stmt.name == "__init__":
+            continue
+        elif isinstance(stmt, ast.AnnAssign):
+            found_assignment_stmt = True
+        else:
+            return False
+    return found_assignment_stmt
 
 
 def pie793_prefer_dataclass(
@@ -23,7 +33,7 @@ def pie793_prefer_dataclass(
         not inside_inheriting_cls
         and not node.bases
         and not node.decorator_list
-        and all(_is_dataclass_like_stmt(stmt) for stmt in node.body)
+        and _has_dataclass_like_body(node.body)
     ):
         errors.append(PIE793(lineno=node.lineno, col_offset=node.col_offset))
 
